CustomerRewardsResponseModel class
Represents the response model for customer rewards API.
Contains an optional message and a list of CustomerRewards items.
Constructors
-
CustomerRewardsResponseModel({String? message, List<
CustomerRewards> ? data}) - Creates a CustomerRewardsResponseModel instance.
-
CustomerRewardsResponseModel.fromJson(Map<
String, dynamic> json) -
Creates a CustomerRewardsResponseModel from a JSON map.
factory
- CustomerRewardsResponseModel.fromRawJson(String str)
-
Creates a CustomerRewardsResponseModel from a raw JSON string.
factory
Properties
-
data
→ List<
CustomerRewards> ? -
List of rewards associated with the customer.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
Response message from the API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this object to a JSON map.
-
toRawJson(
) → String - Converts this object to a raw JSON string.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited